@@ -1,5 +1,5 @@
-__version__ = "0.0.7"
-__keywords__ = ["file host zippyshare archive"]
+__version__ = "0.1.1"
+__keywords__ = ["zippyshare file host batch remote upload captcha recaptcha bypass account register registration api cli manager archive"]
 
 
 if not __version__.endswith(".0"):
